@@ -636,7 +636,7 @@ where
     fn emit_ts_param_prop(&mut self, n: &TsParamProp) -> Result {
         self.emit_leading_comments_of_span(n.span(), false)?;
 
-        self.emit_accesibility(n.accessibility)?;
+        self.emit_accessibility(n.accessibility)?;
 
         if n.is_override {
             keyword!("override");
